@@ -304,7 +304,7 @@ update_apm_status(t_battmon *battmon)
         DBG("old_state=%d, new_state=%d, icon_name=%s", old_state, new_state, icon_name);
 
         if (old_state != new_state)
-            xfce_panel_image_set_from_source(XFCE_PANEL_IMAGE(battmon->image), icon_name);
+            gtk_image_set_from_icon_name(GTK_IMAGE(battmon->image), icon_name, GTK_ICON_SIZE_BUTTON);
         if (icon_name)
             g_free(icon_name);
 
@@ -505,8 +505,8 @@ setup_battmon(t_battmon *battmon)
     battmon->label = (GtkLabel *)gtk_label_new(_("Battery"));
     gtk_box_pack_start(GTK_BOX(battmon->ebox),GTK_WIDGET(battmon->label),FALSE, FALSE, 2);
 
-    battmon->image = xfce_panel_image_new_from_source("xfce4-battery-plugin");
-    xfce_panel_image_set_size(XFCE_PANEL_IMAGE(battmon->image), size);
+    battmon->image = gtk_image_new_from_icon_name("xfce4-battery-plugin", GTK_ICON_SIZE_BUTTON);
+    gtk_image_set_pixel_size(GTK_IMAGE(battmon->image), size);
 
     gtk_box_pack_start(GTK_BOX(battmon->ebox),GTK_WIDGET(battmon->image), FALSE, FALSE, 0);
 
@@ -761,8 +761,10 @@ static gboolean
 battmon_set_size(XfcePanelPlugin *plugin, int size, t_battmon *battmon)
 {
     int border_width;
+    gint icon_size;
 
     size /= xfce_panel_plugin_get_nrows (battmon->plugin);
+    icon_size = xfce_panel_plugin_get_icon_size(XFCE_PANEL_PLUGIN (battmon->plugin));
     border_width = size > 26 ? 2 : 1;
     DBG("set_size(%d)", size);
 
@@ -783,7 +785,7 @@ battmon_set_size(XfcePanelPlugin *plugin, int size, t_battmon *battmon)
 
     gtk_container_set_border_width (GTK_CONTAINER (battmon->ebox), border_width);
     /* update the icon */
-    xfce_panel_image_set_size(XFCE_PANEL_IMAGE(battmon->image), size - (2 * border_width));
+    gtk_image_set_pixel_size(GTK_IMAGE(battmon->image), icon_size);
 
     return TRUE;
 }
@@ -1373,27 +1375,21 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
 static void
 battmon_show_about(XfcePanelPlugin *plugin, t_battmon *battmon)
 {
-   GdkPixbuf *icon;
    const gchar *auth[] = {
         "Benedikt Meurer <benny@xfce.org>", "Edscott Wilson <edscott@imp.mx>",
         "Eduard Roccatello <eduard@xfce.org>", "Florian Rivoal <frivoal@xfce.org>",
         "Landry Breuil <landry@xfce.org>", "Nick Schermer <nick@xfce.org>",
         "Andre Miranda <andreldm@xfce.org>", NULL };
 
-   icon = xfce_panel_pixbuf_from_source("xfce4-battery-plugin", NULL, 32);
-
    gtk_show_about_dialog(NULL,
-        "logo", icon,
+        "logo-icon-name", "xfce4-battery-plugin",
         "license", xfce_get_license_text (XFCE_LICENSE_TEXT_GPL),
         "version", PACKAGE_VERSION,
         "program-name", PACKAGE_NAME,
         "comments", _("Show and monitor the battery status"),
         "website", "https://docs.xfce.org/panel-plugins/xfce4-battery-plugin",
-        "copyright", _("Copyright (c) 2003-2019\n"),
+        "copyright", "Copyright \302\251 2003-2023 The Xfce development team",
         "authors", auth, NULL);
-
-   if (icon)
-      g_object_unref(G_OBJECT(icon));
 }
 
 static void
